@@ -1,6 +1,5 @@
 import json
 import logging
-from typing import List
 
 from pandas import DataFrame
 from pandas.io.json import build_table_schema
@@ -22,13 +21,13 @@ class PipelineExecutor:
     def __init__(self, domain_retriever: DomainRetriever):
         self.retrieve_domain = domain_retriever
 
-    def execute_pipeline(self, pipeline_steps: List[dict]) -> DataFrame:
+    def execute_pipeline(self, pipeline: Pipeline) -> DataFrame:
         """
         Execute a pipeline and returns the result as a pandas DataFrame
         """
         # TODO validate the pipeline, e.g. the first step should always be a domain step
         # self.validate_pipeline()
-        steps = Pipeline(steps=pipeline_steps).steps
+        steps = pipeline.steps
         df = None
         stopwatch = StopWatch()
         for index, step in enumerate(steps):
@@ -46,7 +45,7 @@ class PipelineExecutor:
                 raise PipelineExecutionFailure(step, index, e) from e
         return df
 
-    def preview_pipeline(self, pipeline_steps: List[dict], limit: int = 50, offset: int = 0) -> str:
+    def preview_pipeline(self, pipeline: Pipeline, limit: int = 50, offset: int = 0) -> str:
         """
         Execute a pipeline but returns only a slice of the results, determined by `limit` and `offset` parameters, as JSON.
 
@@ -56,7 +55,7 @@ class PipelineExecutor:
 
         Note: it's required to use pandas `to_json` methods, as it convert NaN and dates to an appropriate format.
         """
-        df = self.execute_pipeline(pipeline_steps)
+        df = self.execute_pipeline(pipeline)
         return json.dumps(
             {
                 'schema': build_table_schema(df, index=False),
